@@ -1,4 +1,4 @@
-/* Copyright 2016 The Tor Project
+/* Copyright 2016--2017 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.cron;
@@ -33,5 +33,11 @@ public class Broken extends CollecTorMain {
   public String module() {
     return "broken";
   }
+
+  @Override
+  protected String syncMarker() {
+    return "Broken";
+  }
+
 }
 
